@@ -104,6 +104,8 @@ int AP1_width(mapStr2intVec& IntFeatureData,
               mapStr2doubleVec& DoubleFeatureData, mapStr2Str& StringData);
 int AP2_width(mapStr2intVec& IntFeatureData,
               mapStr2doubleVec& DoubleFeatureData, mapStr2Str& StringData);
+int APlast_width(mapStr2intVec& IntFeatureData,
+              mapStr2doubleVec& DoubleFeatureData, mapStr2Str& StringData);
 
 int AHP_depth_from_peak(mapStr2intVec& IntFeatureData,
                         mapStr2doubleVec& DoubleFeatureData,
@@ -193,6 +195,12 @@ int min_voltage_between_spikes(mapStr2intVec& intfeaturedata,
 int voltage(mapStr2intVec& intfeaturedata,
                                   mapStr2doubleVec& doublefeaturedata,
                                   mapStr2Str& StringData);
+int current(mapStr2intVec& intfeaturedata,
+                                  mapStr2doubleVec& doublefeaturedata,
+                                  mapStr2Str& StringData);
+int time(mapStr2intVec& intfeaturedata,
+                                  mapStr2doubleVec& doublefeaturedata,
+                                  mapStr2Str& StringData);
 int steady_state_voltage_stimend(mapStr2intVec& IntFeatureData,           
                                  mapStr2doubleVec& DoubleFeatureData,             
                                  mapStr2Str& StringData);
